<?php
// $Id: leaguesite.admin.inc,v 1.2 2010/01/24 23:54:23 alun Exp $

/**
 * @file
 * Administrative page callbacks for the league module.
 */

/**
 * Admin form for the seasons page
 */
function leaguesite_admin(){
	//get the seasons from the database for the list display
	//TODO: Anywhere I display the date should be formatted to a custom format, can use get and set variable on a config form I need to create
	$seasons = db_query("SELECT * FROM {leaguesite_season} ORDER BY name ASC");
	$count = 0;

	while($row = db_fetch_array($seasons)){
		$form[$row['sid']]['name'] = array('#value' => $row['name'],);
		$form[$row['sid']]['start'] = array('#value' => date("d M y", $row['start']));
		$form[$row['sid']]['end'] = array('#value' => date("d M y", $row['end']));
		$form[$row['sid']]['view'] = array('#value' => l(t('view'), 'admin/content/leaguesite/view_season/'. $row['sid']));
		$form[$row['sid']]['configure'] = array('#value' => l(t('configure'), 'admin/content/leaguesite/edit_season/'. $row['sid']));
		$form[$row['sid']]['delete'] = array('#value' => $default ? '' : l(t('delete'), 'admin/content/leaguesite/delete_season/'. $row['sid']));
		++$count;
	}
	if($count == 0){
		$form['notice'] = array('#value' => 'No seasons currently exist, please add one above.');
	}
	return $form;
}

function leaguesite_list(){
	$leagues = db_query("SELECT * FROM {leaguesite_league};");
	//TODO: sort out count of seasons in this view?
	$count = 0;
	while($row = db_fetch_array($leagues)){
		$form[$row['lid']]['name'] = array('#value' => $row['name'],);
		$form[$row['lid']]['weeks'] = array('#value' => $row['weeks']);
		$form[$row['lid']]['configure'] = array('#value' => l(t('configure'), 'admin/content/leaguesite/leagues/edit/'. $row['lid']));
		$form[$row['lid']]['delete'] = array('#value' => $default ? '' : l(t('delete'), 'admin/content/leaguesite/delete_league/'. $row['lid']));
		++$count;
	}
	if($count == 0){
		$form['notice'] = array('#value' => 'No leagues currently exist, please add one above.');
	}

	return $form;
}

/**
 * Add season form for the league admin page
 */
function leaguesite_add(){

	$breadcrumb = drupal_get_breadcrumb();
	$breadcrumb[] = l(t('Leagues'), 'admin/content/leaguesite/leagues');
	drupal_set_breadcrumb($breadcrumb);

	//get the scoring details
	$result = db_query("SELECT * FROM {leaguesite_scores};");
	$scores[] = array();
	while($row = db_fetch_array($result)){
		$scores[$row['score_id']] = t($row['name']);
	}
	//$scores['other'] = t('Other');
	$form = array();
	//add a new season
	$form['league_name'] = array(
    '#type' => 'textfield',
    '#title' => t('League Name'),
    '#description' => t('The name of your league'),
    '#size' => 30,
    '#maxlength' => 64,
    '#required' => TRUE,
	);
	$form['league_weeks'] = array(
    '#type' => 'textfield',
    '#title' => t('Match Weeks'),  
    '#description' => t('Set the number of weeks you play matches for over the course of the season. Default value is 10.'),
    '#size' => 3,
    '#maxlength' => 3,
    '#required' => FALSE,
	);
	$form['league_type'] = array(
    '#type' => 'select',
    '#title' => t('Scoring type used in league'),
    '#options' => $scores,
    '#description' => t('Choose a scoring type, if the suitable one exists. You can change it later. If you cannot find the one you want, you can add a scoring type.'),
	);
	$form['submit'] = array(
    '#type' => 'submit', '#value' => t('Create League')
	);
	return $form;
}

function leaguesite_edit(){
	//get the season and the details for the form
	$league = arg(5);
	if(is_numeric($league)){

		//get the scoring details
		$result = db_query("SELECT * FROM {leaguesite_scores};");
		$scores[] = array();
		while($row = db_fetch_array($result)){
			$scores[$row['score_id']] = t($row['name']);
		}
		 
		$breadcrumb = drupal_get_breadcrumb();
		$breadcrumb[] = l(t('Leagues'), 'admin/content/leaguesite/leagues');
		drupal_set_breadcrumb($breadcrumb);
		 
		$result = db_fetch_array(db_query("SELECT leaguesite_league.*, leaguesite_scores.score_id FROM {leaguesite_league, leaguesite_scores} WHERE lid = %d AND leaguesite_league.score_id = leaguesite_scores.score_id", $league));
		$form = array();
		//add a new league form
		$form['league_name'] = array(
      '#type' => 'textfield',
      '#title' => t('League Name'),
      '#description' => t('The name of your league'),
      '#size' => 30,
      '#maxlength' => 50,
      '#required' => TRUE,
      '#default_value' => $result['name'],
		);
		$form['league_id'] = array(
      '#type' => 'hidden',
      '#value' => $league,
		);
		$form['league_weeks'] = array(
      '#type' => 'textfield',
      '#title' => t('Match Weeks'),  
      '#description' => t('The number of weeks you play matches for over the course of the season. Default value is 10.'),
      '#size' => 3,
      '#maxlength' => 3,
      '#required' => FALSE,
      '#default_value' => $result['weeks'],
		);

		$form['league_type'] = array(
      '#type' => 'select',
      '#title' => t('Type of League'),
      '#default_value' => $result['score_id'],
      '#options' => $scores,
      '#description' => t('Choose a league type, if the suitable one exists. This will automatically set up the points scoring system which can be edited later if needs be.'),
		);

		$form['submit'] = array(
      '#type' => 'submit', '#value' => t('Amend League')
		);
		return $form;
	}else{
		drupal_not_found();
	}
}

/**
 * Function to deal with deleting a selected season
 */
function leaguesite_delete_league(){
	$league = arg(4);
	$league = db_fetch_array(db_query('SELECT * FROM {leaguesite_league} WHERE lid = %d;', $league));

	if ($league) {
		$form['league'] = array('#type' => 'hidden', '#value' => $league['lid']);
		$form['name'] = array('#type' => 'hidden', '#value' => $league['name']);
		return confirm_form($form, t('Are you sure you want to delete the league %league?', array('%league' => $league['name'])), 'admin/content/leaguesite/leagues', t('Deleting this league will not remove teams in it, but all the table standings will be lost.'), t('Delete'), t('Cancel'));
	}
	else {
		drupal_not_found();
	}
}

/**
 * Function to validate the edit form before saving the changes
 * @param $form
 * @param $form_state
 */
function leaguesite_add_validate($form, $form_state){
	//Check the name of the league name
	$result = db_fetch_array(db_query("SELECT name FROM {leaguesite_league} WHERE name = '%s'", mysql_escape_string($form_state['values']['league_name'])));

	//TODO: Add a link to edit the league they match?
	if($result){
		form_set_error('league_name', t('You already have a league with this name. Please choose a different name. Or you could edit this league.'));
	}
}

/**
 * Function to deal with the submission of the create/edit league form
 */
function leaguesite_add_submit($form, $form_state){
	//add the league to the database.
	$name = check_plain($form_state['values']['league_name']);
	$weeks = intval($form_state['values']['league_weeks']);
	$scoring = intval($form_state['values']['league_type']);
	db_query("INSERT INTO {leaguesite_league} (name, weeks, score_id) VALUES('%s', %d, %d);", $name, $weeks, $scoring);
	//not sure why I typed this, but it seems irrelevent?
	//$id = db_fetch_array(db_query("SELECT LAST_INSERT_ID() AS id;"));
	drupal_set_message(t('Added league %league.', array('%league' => $name)));
}

/**
 * Function to delete selected league
 */
function leaguesite_delete_league_submit($form, $form_state){
	//remove the season from the table. In the future, also will have to delete all standings related to the season too
	$league_id = $form_state['values']['league'];
	db_query("DELETE FROM {leaguesite_league} WHERE lid = %d", $league_id);
	drupal_set_message(t('League deleted.'));
	drupal_goto('admin/content/leaguesite');
}

/**
 * Function to save changes made to a season
 * @param $form
 * @param $form_state
 */
function leaguesite_edit_submit($form, $form_state){
	//TODO: Currently, the points system is not being saved.
	$name = check_plain($form_state['values']['league_name']);
	$weeks = intval($form_state['values']['league_weeks']);
	$score_id = intval($form_state['values']['league_type']);
	$lid = intval($form_state['values']['league_id']);
	db_query("UPDATE {leaguesite_league} SET name = '%s', weeks = %d, score_id = %d WHERE lid = %d;", $name, $weeks, $score_id, $lid);
	drupal_set_message(t('Changes Saved'));
}


/**
 * Function to show a leagues details and allow a user to add teams to the league.
 * @return $form - the form for the editing of the league.
 */
function leaguesite_view(){
	/*Show the details of the league, then a list of checkboxes for each team.
	 * Tick the ones currently in the league, and allow the user to tick and untick before submitting
	 */
	$season = arg(5);
	$league = arg(6);
	if(is_numeric($league) && is_numeric($season)){
		//get the league details.
		$result = db_fetch_array(db_query("SELECT leaguesite_league.name AS leaguename, leaguesite_league.weeks, leaguesite_season.name FROM {leaguesite_league, leaguesite_season, leaguesite_relation} WHERE leaguesite_league.lid = leaguesite_relation.lid AND leaguesite_relation.sid = leaguesite_season.sid AND leaguesite_relation.lid = %d AND leaguesite_relation.sid=%d;", $league, $season));
		drupal_set_title(t('Viewing league %league', array('%league' => $result['leaguename'])));
		$breadcrumb = drupal_get_breadcrumb();
		$breadcrumb[] = l($result['name'], 'admin/content/leaguesite/view_season/'.$season);
		drupal_set_breadcrumb($breadcrumb);
		if($result){
			//get the details
			$weeks = $result['weeks'];
			//TODO: The layout of these labels should be sorted out!!
			$form['start'] = array('#value' => t('Weeks: ').$weeks);
			$form['teams'] = array(
        '#type' => 'fieldset',
        '#title' => t('Teams in the league for '.$result['name']),
         '#description' => t('Note, if you remove any of these teams from the league after the start of a season, the matches stay intact, but they lose their standing in the table.'),
			);
			//list the teams available, like the season view, where I can tick the teams involved in the league.
			$all_teams = db_query("SELECT node.nid, node.title FROM {node} WHERE node.type = 'leaguesite_team' AND node.status = 1 ORDER BY node.nid;");
			$enabled_teams_result = db_query("SELECT {node}.nid FROM {node, leaguesite_relation, leaguesite_standings} WHERE {leaguesite_relation}.relation_id={leaguesite_standings}.relation_id AND {node}.type = 'leaguesite_team' AND {leaguesite_standings}.team_id = {node}.nid AND {leaguesite_relation}.lid = %d AND {leaguesite_relation}.sid = %d ORDER BY {node}.nid;", $league, $season);
			$enabled_teams = db_fetch_array($enabled_teams_result);
			$count = 0;
			while($row = db_fetch_array($all_teams)){
				++$count;
				if($enabled_teams['nid'] == $row['nid']){
					//the current row is present in the league.
					$ticked = TRUE;
					//get the next enabled one
					$enabled_teams = db_fetch_array($enabled_teams_result);
				}else{
					$ticked = FALSE;
				}
				$form['teams'][$row['nid']] = array(
          '#type' => 'checkbox',
          '#title' => $row['title'],
          '#default_value' => $ticked,
				);
			}
			if($count == 0){
				$form['teams']['label'] = array(
          '#value' => t('No teams added yet, go to create content to add a team'),
				);
			}else{
				$form['submit'] = array(
          '#type' => 'submit', '#value' => t('Make Changes')
				);
			}

		}
	}else{
		drupal_not_found();
	}
	return $form;
}

/**
 * Function to deal with the submit of the league view - look through all the teams and add / remove standings information as appropriate
 */
function leaguesite_view_submit($form, $form_state){
	$season = arg(5);
	$league = arg(6);
	$result = db_fetch_array(db_query("SELECT relation_id FROM {leaguesite_relation} WHERE lid = %d AND sid = %d", $league, $season));
	$relation_id = $result['relation_id'];
	if(!is_numeric($season) || !is_numeric($league)){
		drupal_not_found();
	}else{
		//loop through the form league values and add/remove the league_relation as appropriate
		foreach($form_state['values'] as $id => $checked){
			//get the value from league_relation and check to see it matches the chosen state in the tickbox
			$result = db_fetch_array(db_query("SELECT node.nid FROM {node, leaguesite_relation, leaguesite_standings} WHERE leaguesite_relation.relation_id=leaguesite_standings.relation_id AND leaguesite_relation.lid = %d AND leaguesite_relation.sid = %d AND node.nid = leaguesite_standings.team_id AND leaguesite_standings.team_id = %d ORDER BY {node.nid};", $league, $season, check_plain($id)));
			if(($result == FALSE && $checked == 1) || ($result != FALSE && $checked == 0)){
				if($checked == 1){
					//if checked equals 1, then add the relation
					db_query("INSERT INTO {leaguesite_standings} (relation_id,team_id) VALUES (%d, %d)", $relation_id, check_plain($id));
				}else if($checked == 0){
					//if checked equals 0, then delete the relation
					db_query("DELETE FROM {leaguesite_standings} WHERE team_id = %d AND relation_id = %d", check_plain($id), $relation_id);
				}
			}
		}
		drupal_set_message("Changes Saved");
	}
}

/**
 * Theme the admin overview form.
 *
 * @ingroup themeable
 */
function theme_leaguesite_admin($form) {
	$seasonrows = array();
	foreach ($form as $name => $element) {
		if(is_array($element['name'])){
			$seasonrows[] = array(
			drupal_render($element['name']),
			check_plain($element['start']['#value']),
			check_plain($element['end']['#value']),
			drupal_render($element['view']),
			drupal_render($element['configure']),
			drupal_render($element['delete'])
			);
			unset($form[$name]);
		}
	}
	$seasonheader = array(t('Season Name'), t('Starts'), t('Ends'), array('data' => t('Operations'), 'colspan' => 3));
	if(count($seasonrows) > 0){
		$output = theme('table', $seasonheader, $seasonrows);
	}
	$output .= l('Add a new season', 'admin/content/leaguesite/add');
	return $output;
}

/**
 * Theme the league list form
 */
function theme_leaguesite_list($form) {
	$leaguerows = array();
	foreach ($form as $name => $element) {
		if(is_array($element['name'])){
			$leaguerows[] = array(
			drupal_render($element['name']),
			check_plain($element['weeks']['#value']),
			drupal_render($element['configure']),
			drupal_render($element['delete'])
			);
			unset($form[$name]);
		}
	}
	$leagueheader = array(t('League Name'), t('Weeks'), array('data' => t('Operations'), 'colspan' => 2));
	if(count($leaguerows) > 0){
		$output = theme('table', $leagueheader, $leaguerows);
	}
	$output .= l('Add a new league', 'admin/content/leaguesite/leagues/add');
	return $output;
}