<?php
/**
 * Function to get and list the scoring methods of the leagues
 * @return $form listing the details of the scoring types available
 */
function leaguesite_scoring_list(){
	$leagues = db_query("SELECT * FROM {leaguesite_scores};");
	$count = 0;

	while($row = db_fetch_array($leagues)){
		$form[$row['score_id']]['name'] = array('#value' => $row['name'],);
		$form[$row['score_id']]['win'] = array('#value' => $row['win']);
		$form[$row['score_id']]['draw'] = array('#value' => $row['draw']);
		$form[$row['score_id']]['lose'] = array('#value' => $row['loss']);
		$form[$row['score_id']]['configure'] = array('#value' => l(t('configure'), 'admin/content/leaguesite/scores/edit/'. $row['score_id']));
		$form[$row['score_id']]['delete'] = array('#value' => $default ? '' : l(t('delete'), 'admin/content/leaguesite/scores/delete/'. $row['score_id']));
		++$count;
	}
	if($count == 0){
		$form['notice'] = array('#value' => 'No scoring methods currently exist.');
	}


	return $form;
}

/**
 * Theme the scoring output
 * @param Array $form - the form to render
 * @return $output - rendered output.
 */
function theme_leaguesite_scoring_list($form) {
	$scorerows = array();
	foreach ($form as $name => $element) {
		if(is_array($element['name'])){
			$scorerows[] = array(
			drupal_render($element['name']),
			drupal_render($element['win']),
			drupal_render($element['draw']),
			drupal_render($element['lose']),
			drupal_render($element['configure']),
			drupal_render($element['delete'])
			);
			unset($form[$name]);
		}
	}
	$seasonheader = array(t('Scoring System'), t('Win'), t('Draw'), t('Lose'), array('data' => t('Operations'), 'colspan' => 2));
	if(count($scorerows) > 0){
		$output = theme('table', $seasonheader, $scorerows);
	}
	$output .= l('Add a new score type', 'admin/content/leaguesite/scores/add');
	return $output;
}

function leaguesite_score_add(){
	$breadcrumb = drupal_get_breadcrumb();
	$breadcrumb[] = l(t('Scores'), 'admin/content/leaguesite/scores');
	drupal_set_breadcrumb($breadcrumb);

	$form = array();
	//add a new season
	$form['score_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Scoring type name'),
    '#description' => t('The name of the scoring type'),
    '#size' => 30,
    '#maxlength' => 64,
    '#required' => TRUE,
	);
	$form['score_win'] = array(
    '#type' => 'textfield',
    '#title' => t('Points for a win'),  
    '#description' => t('Number of points a team achieves for a win.'),
    '#size' => 3,
    '#maxlength' => 3,
    '#required' => FALSE,
	);
	$form['score_draw'] = array(
    '#type' => 'textfield',
    '#title' => t('Points for a draw'),
    '#size' => 3,
    '#maxlength' => 3,
    '#description' => t('Number of a points a team acheve for a draw.'),
	);
	$form['score_lose'] = array(
    '#type' => 'textfield',
    '#title' => t('Points for a loss'),
    '#size' => 3,
    '#maxlength' => 3,
    '#description' => t('Number of points achieved for a loss.'),
	);
	$form['submit'] = array(
    '#type' => 'submit', '#value' => t('Create Scoring Type'),
	);
	return $form;
}

/**
 * Function to add the score type to the database
 * @param unknown_type $form
 * @param unknown_type $form_state
 * @return none
 */
function leaguesite_score_add_submit($form, $form_state){
	$score_name = check_plain($form_state['values']['score_name']);
	$score_win = intval($form_state['values']['score_win']);
	$score_draw = intval($form_state['values']['score_draw']);
	$score_lose = intval($form_state['values']['score_loss']);
	db_query("INSERT INTO {leaguesite_scores} (name, win, draw, loss) VALUES ('%s', %d, %d, %d);", $score_name, $score_win, $score_draw, $score_lose);
	drupal_set_message(t('Added score type %score.', array('%score' => $score_name)));
}

function leaguesite_score_edit(){
	$breadcrumb = drupal_get_breadcrumb();
	$breadcrumb[] = l(t('Scores'), 'admin/content/leaguesite/scores');
	drupal_set_breadcrumb($breadcrumb);

	$score_id = arg(5);
	$score = db_fetch_array(db_query("SELECT * FROM {leaguesite_scores} WHERE score_id = %d", $score_id));

	$form = array();
	$form['score_id'] = array(
    '#value' => $score_id,
    '#type' => 'hidden',
	);
	$form['score_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Scoring type name'),
    '#description' => t('The name of the scoring type'),
    '#size' => 30,
    '#maxlength' => 64,
    '#default_value' => $score['name'],
    '#required' => TRUE,
	);
	$form['score_win'] = array(
    '#type' => 'textfield',
    '#title' => t('Points for a win'),  
    '#description' => t('Number of points a team achieves for a win.'),
    '#size' => 3,
    '#maxlength' => 3,
    '#default_value' => $score['win'],
    '#required' => FALSE,
	);
	$form['score_draw'] = array(
    '#type' => 'textfield',
    '#title' => t('Points for a draw'),
    '#size' => 3,
    '#maxlength' => 3,
    '#default_value' => $score['draw'],
    '#description' => t('Number of a points a team acheve for a draw.'),
	);
	$form['score_lose'] = array(
    '#type' => 'textfield',
    '#title' => t('Points for a loss'),
    '#size' => 3,
    '#maxlength' => 3,
    '#default_value' => $score['loss'],
    '#description' => t('Number of points achieved for a loss.'),
	);
	$form['submit'] = array(
    '#type' => 'submit', '#value' => t('Amend scoring type'),
	);
	return $form;
}

/**
 * Function to submit the edited score type to the database
 * @param unknown_type $form
 * @param unknown_type $form_state
 * @return none
 */
function leaguesite_score_edit_submit($form, $form_state){
	$score_name = check_plain($form_state['values']['score_name']);
	$score_win = intval($form_state['values']['score_win']);
	$score_draw = intval($form_state['values']['score_draw']);
	$score_lose = intval($form_state['values']['score_loss']);
	$score_id = intval($form_state['values']['score_id']);
	db_query("UPDATE {leaguesite_scores} SET name = '%s', win = %d, draw = %d, loss = %d WHERE score_id = %d;", $score_name, $score_win, $score_draw, $score_lose, $score_id);
	drupal_set_message(t('Edited score type %score.', array('%score' => $score_name)));
}

function leaguesite_score_delete(){
	$score_id = arg(5);
	$score = db_fetch_array(db_query('SELECT * FROM {leaguesite_scores} WHERE score_id = %d;', $score_id));

	if ($score) {
		$form['score'] = array('#type' => 'hidden', '#value' => $score['score_id']);
		$form['name'] = array('#type' => 'hidden', '#value' => $score['name']);
		return confirm_form($form, t('Are you sure you want to delete the scoring type %score?', array('%score' => $score['name'])), 'admin/content/leaguesite/scores', t('Warning, if you have leagues using this scoring type, this will cause problems calculating league standings.'), t('Delete'), t('Cancel'));
	}
	else {
		drupal_not_found();
	}
}

/**
 * Function to delete selected score type
 */
function leaguesite_score_delete_submit($form, $form_state){
	//remove the season from the table. In the future, also will have to delete all standings related to the season too
	$score_id = $form_state['values']['score'];
	if(is_numeric($score_id)){
		db_query("DELETE FROM {leaguesite_scores} WHERE score_id = %d", $score_id);
		drupal_set_message(t('Scoring type deleted.'));
	}
	drupal_goto('admin/content/leaguesite/scores');
}