<?php
// $Id: leaguesite.season.admin.inc,v 1.2 2010/01/24 23:54:23 alun Exp $

/**
 * @file
 * Administrative page callbacks for the season view, delete and edit of the league module.
 */

/**
 * Add season form for the league admin page
 */
function leaguesite_season_add(){
	$form = array();
	//add a new season
	$form['season_name'] = array(
    '#type' => 'textfield',
    '#title' => t('Name'),
    '#description' => t('The name of your season'),
    '#size' => 30,
    '#maxlength' => 50,
    '#required' => TRUE,
	);

	$form['season_startdate'] = array(
    '#type' => 'date',
    '#title' => t('Start Date'),  
    '#description' => t('Select when your season starts. If you do not know the exact day, set it sometime in the middle of the season break'),
    '#required' => TRUE,
	);
	$form['season_enddate'] = array(
    '#type' => 'date',
    '#title' => t('End Date'),  
    '#description' => t('Select when your season ends.'),
    '#required' => TRUE,
	);
	$form['submit'] = array(
    '#type' => 'submit', '#value' => t('Create Season')
	);
	return $form;
}

function leaguesite_season_edit(){
	//get the season and the details for the form
	$season = arg(4);
	if(is_numeric($season)){
		$result = db_fetch_array(db_query("SELECT * FROM {leaguesite_season} WHERE sid = %d", $season));
		$form = array();
		//edit the season
		$form['season_name'] = array(
      '#type' => 'textfield',
      '#title' => t('Name'),
      '#description' => t('The name of your season'),
      '#size' => 30,
      '#maxlength' => 64,
      '#required' => TRUE,
      '#default_value' => $result['name'],
		);

		$form['season_old_name'] = array(
      '#type' => 'hidden',
      '#value' => $result['name'],
		);
		$form['season_id'] = array(
      '#type' => 'hidden',
      '#value' => $season,
		);

		$form['season_startdate'] = array(
      '#type' => 'date',
      '#title' => t('Start Date'),  
      '#description' => t('Select when your season starts. If you do not know the exact day, set it sometime in the middle of the season break'),
      '#required' => TRUE,
      '#default_value' => array('year'=>date("Y",$result['start']), 'month'=>date("n",$result['start']), 'day'=>date("j",$result['start'])),
		);
		$form['season_enddate'] = array(
      '#type' => 'date',
      '#title' => t('End Date'),  
      '#description' => t('Select when your season ends.'),
      '#required' => TRUE,
      '#default_value' => array('year'=>date("Y",$result['end']), 'month'=>date("n",$result['end']), 'day'=>date("j",$result['end'])),
		);
		$form['submit'] = array(
      '#type' => 'submit', '#value' => t('Save Changes')
		);
		return $form;
	}else{
		drupal_not_found();
	}
}

/**
 * Function to deal with deleting a selected season
 */
function leaguesite_season_delete(){
	$season = arg(4);
	$season = db_fetch_array(db_query('SELECT * FROM {leaguesite_season} WHERE sid = %d;', $season));

	if ($season) {
		$form['season'] = array('#type' => 'hidden', '#value' => $season['sid']);
		$form['name'] = array('#type' => 'hidden', '#value' => $season['name']);
		return confirm_form($form, t('Are you sure you want to delete the season %season?', array('%season' => $season['name'])), 'admin/content/leaguesite/', t('Deleting this season will not remove the leagues and teams, but all the table standings will be lost.'), t('Delete'), t('Cancel'));
	}
	else {
		drupal_not_found();
	}
}

/**
 * Validate the season input - the end date has to be later than the start date
 * @return unknown_type
 */
function leaguesite_season_add_validate($form, $form_state){
	$result = db_fetch_array(db_query("SELECT name FROM {leaguesite_season} WHERE name = '%s'", mysql_escape_string($form_state['values']['season_name'])));
	if($result){
		form_set_error('season_name', t('You already have a season with this name. Please choose a different name'));
	}
	$start = $form_state['values']['season_startdate'];
	$end = $form_state['values']['season_enddate'];
	if((mktime(0, 0, 0, intval($start['month']), intval($start['day']), intval($start['year']))) >= (mktime(0, 0, 0, intval($end['month']), intval($end['day']), intval($end['year'])))){
		form_set_error('season_enddate', t('Your season finish time cannot be earlier than the end time, or be the same day'));
	}
}

/**
 * Function to validate the edit form before saving the changes
 * @param $form
 * @param $form_state
 */
function leaguesite_season_edit_validate($form, $form_state){
	//if the user has changed the name, check it does not equal another season name
	if($form_state['values']['season_name'] != $form_state['values']['season_old_name']){
		$result = db_fetch_array(db_query("SELECT name FROM {leaguesite_season} WHERE name = '%s'", mysql_escape_string($form_state['values']['season_name'])));

		if($result){
			form_set_error('season_name', t('You already have a season with this name. Please choose a different name'));
		}
	}
	$start = $form_state['values']['season_startdate'];
	$end = $form_state['values']['season_enddate'];
	if((mktime(0, 0, 0, intval($start['month']), intval($start['day']), intval($start['year']))) >= (mktime(0, 0, 0, intval($end['month']), intval($end['day']), intval($end['year'])))){
		form_set_error('season_enddate', t('Your season finish time cannot be earlier than the end time, or be the same day'));
	}
}

/**
 * Function to deal with the submission of the create/edit season form
 */
function leaguesite_season_add_submit($form, $form_state){
	//check submission, then add the season to the database. If update, we should find the edited season and change the settings.
	$name = mysql_escape_string($form_state['values']['season_name']);
	$start = mktime(0,0,0,$form_state['values']['season_startdate']['month'], $form_state['values']['season_startdate']['day'], $form_state['values']['season_startdate']['year']);
	$end = mktime(0,0,0,intval($form_state['values']['season_enddate']['month']), intval($form_state['values']['season_enddate']['day']), intval($form_state['values']['season_enddate']['year']));
	db_query("INSERT INTO {leaguesite_season} (name, start, end) VALUES('%s', %d, %d);", $name, $start, $end);
	drupal_set_message(t('Added season %season.', array('%season' => $name)));
}

/**
 * Function to delete selected season
 */
function leaguesite_season_delete_submit($form, $form_state){
	//remove the season from the table. In the future, also will have to delete all standings related to the season too
	$season_id = $form_state['values']['season'];
	db_query("DELETE FROM {leaguesite_season} WHERE sid = %d", $season_id);
	drupal_set_message(t('Season deleted.'));
	drupal_goto('admin/content/leaguesite');
}

/**
 * Function to save changes made to a season
 * @param $form
 * @param $form_state
 */
function leaguesite_season_edit_submit($form, $form_state){
	$name = mysql_escape_string($form_state['values']['season_name']);
	$start = mktime(0,0,0,$form_state['values']['season_startdate']['month'], $form_state['values']['season_startdate']['day'], $form_state['values']['season_startdate']['year']);
	$end = mktime(0,0,0,intval($form_state['values']['season_enddate']['month']), intval($form_state['values']['season_enddate']['day']), intval($form_state['values']['season_enddate']['year']));
	$season = $form_state['values']['season_id'];
	db_query("UPDATE {leaguesite_season} SET name = '%s', start = %d, end = %d WHERE sid = %d;", $name, $start, $end, $season);
	drupal_set_message(t('Changes Saved'));
}


/**
 * Function to show a season details and allow a user to add leagues to the season.
 * @return $form - the form for the editing.
 */
function leaguesite_season_view(){
	/*Show the details of the season, then a list of checkboxes for each league.
	 * Tick the ones added currently, and allow the user to tick and untick before submitting
	 */
	$season = arg(4);
	if(is_numeric($season)){
		$result = db_fetch_array(db_query("SELECT * FROM {leaguesite_season} WHERE sid = %d;", $season));
		if($result){
			//get the details
			$name = $result['name'];
			drupal_set_title(t('View season %season', array('%season' => $name)));
			$starts = date("d M y",$result['start']);
			$ends = date("d M y", $result['end']);
			//TODO: The layout of these labels should be sorted out!!
			$form['start'] = array('#value' => t('Starts: ').$starts);
			$form['end'] = array('#value' => t('Ends: ').$ends);
			$form['leagues'] = array(
        '#type' => 'fieldset',
        '#title' => t('Leagues currently running in this season'),
			   '#description' => t('Note, if you remove any of these after entering match information, you will remove all the team standings information from the tables for this season.'),
			);
			//get the leagues list and show them below
			$all_leagues = db_query("SELECT * FROM {leaguesite_league} ORDER BY leaguesite_league.lid;");
			$enabled_leagues_result = db_query("SELECT leaguesite_relation.lid FROM {leaguesite_relation, leaguesite_league} WHERE leaguesite_relation.sid=%d ORDER BY leaguesite_league.lid;", $season);
			$enabled_leagues = db_fetch_array($enabled_leagues_result);
			while($row = db_fetch_array($all_leagues)){
				if($enabled_leagues['lid'] == $row['lid']){
					//the current row is present in the league.
					$ticked = TRUE;
					$link = ' ('.l(t('View Teams'), 'admin/content/leaguesite/leagues/view/'.$season."/".$row['lid']).')';
					$link .= ' or ('.l(t('Edit Standings'), 'admin/content/leaguesite/edit_standings/'.$season."/".$row['lid']).')';
					//get the next enabled one
					$enabled_leagues = db_fetch_array($enabled_leagues_result);
				}else{
					$ticked = FALSE;
					$link = '';
				}
				$form['leagues'][$row['lid']] = array(
          '#type' => 'checkbox',
          '#title' => $row['name'].$link,
          '#default_value' => $ticked,
				);
				$form['submit'] = array(
          '#type' => 'submit', '#value' => t('Make Changes')
				);
			}
		}else{
			drupal_not_found();
		}
	}else{
		drupal_not_found();
	}
	return $form;
}

/**
 * Function to deal with the submission of the season view - users can select what leagues are present in the season.
 * @param $form - the form being submitted
 * @param $form_state - values entered in the form
 */
function leaguesite_season_view_submit($form, $form_state){
	$season = arg(4);
	if(!is_numeric($season)){
		drupal_not_found();
	}else{
		//loop through the form league values and add/remove the league_relation as appropriate
		foreach($form_state['values'] as $id => $checked){
			//get the value from league_relation and check to see it matches the chosen state in the tickbox
			$result = db_fetch_array(db_query("SELECT * FROM {leaguesite_relation} WHERE lid = %d AND sid = %d", check_plain($id), $season));
			if(($result == FALSE && $checked == 1) || ($result != FALSE && $checked == 0)){
				if($checked == 1){
					//if checked equals 1, then add the relation
					db_query("INSERT INTO {leaguesite_relation} (sid, lid) VALUES (%d, %d)", $season, $id);
				}else if($checked == 0){
					//if checked equals 0, then delete the relation
					db_query("DELETE FROM {leaguesite_relation} WHERE lid = %d", check_plain($id));
				}
			}
		}
		drupal_set_message("Changes Saved");
	}
}
